@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20111031';
+our $VERSION = '0.20111130';
 
-# Table last modified: 2011-10-31
+# Table last modified: 2011-11-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -106,17 +106,17 @@ our %ZIP_TABLE = (
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|2(?:46|70|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
     '101' => '(?:8(?:3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|7[6-9]|0[1-46-9]|3[0-5]|1[0-24-69]|2[0-3568])|4(?:7[05-7]|8[13]|0[57-9]|3[0379]|4[13-9]|6[04-9]|5[0-46-9]|2[125]|1[0-25689])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578]|0[2-68])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|7[0237]|5[035-7]|6[248]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|1[125689])|79[58]))',
-    '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-256]|3[0-57-9]|1[0-79]|8[01467]|5[016]|4[3489])|2(?:3\d|0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|8[457]|2[124589]|5[0-25689])|5(?:0[1-367]|4[2358]|8[4-689]|[12][0-25]|5[24-68]|3[013-8]|6[067]|7[0157])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:1[01589]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|4[0468]|3[03589]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[01458]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:3[24-79]|0[124578]|8[02-8]|1[0-24-689]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|5[02-8]|0[579]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
+    '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-256]|3[0-57-9]|1[0-79]|8[01467]|5[016]|4[3489])|2(?:3\d|0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|8[457]|2[124589]|5[0-25689])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|4[0468]|3[03589]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[01458]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '105' => '(?:(?:8(?:4(?:3[24-79]|0[124578]|8[02-8]|1[0-24-689]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|0[57-9]|5[02-8]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|3[25]|1[458]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069]|4[0-24589])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:5(?:8[13589]|2[0-24578]|5[0-26-8]|4[356]|3[023]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|6[78]|2[023578]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:20|34|56|77|0[134]|8[24]|6[067]|1[04679]|4[08])|3(?:55|4[028]|7[013]|2[0346]|3[01568]|8[08])|0(?:06|77)))',
-    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|6[124-8]|4[03-578]|5[0-35-9]|0[1-3569]|2[035]|1[0258]|8[013568])|3(?:3[13489]|1[137]|6[0168]|0[357]|7[0-37-9]|5[0158]|8[134689]|4[15]|2[0-35689])|4(?:0[347]|8[45]|6[67]|5[16]|7[478]|2[013-5]|3[029]|1[0-24-7]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
+    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|6[124-8]|4[03-578]|5[0-35-9]|0[1-3569]|2[035]|1[0258]|8[013568])|3(?:3[13489]|1[137]|6[0168]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|2[0-35689])|4(?:0[347]|8[45]|6[67]|5[16]|7[478]|2[013-5]|3[029]|1[0-24-7]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[058]|7[135-8]|8[015-8])|7(?:8[027]|5[057]|1[2-6]|0[168]|4[05]|3[36]|2[1-35])|80[78]|408))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
     '112' => '(?:8(?:6(?:90|0[167]|2[02579]|4[24]|7[0178]|8[0-57]|3[02-5]|1[0-28]|6[02-478]|5[0-2457])|5(?:8[025]|4[018]|6[02369]|3[138]|2[248]|0[1-35689]|5[015-8]|1[0-24-6]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
-    '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|86|0[13-579]|6[0-46]|4[1369]|2[014-6]|3[04-6]|1[039]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
+    '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|86|0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[013-5]|1[02-57-9]|7[147]|2[0-2468]|5[02-57]|3[0-24589])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:[06]7|55|8[568]|1[01]|2[49])|(?:60|71)1))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-26]|8[014-8]|4[013689]|0[1-3578]|3[237])|611))',
@@ -144,7 +144,7 @@ our %ZIP_TABLE = (
     '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|5[24589]|7[0-46-8]|9[01]|0[2-579])|6(?:00|7[1-7])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:6[05-7]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|7[01378]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[01458]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
-    '154' => '(?:8(?:5(?:8[0-245]|0[3-6]|4[3-5]|2[0135]|3[0-369]|6[5-8]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
+    '154' => '(?:8(?:5(?:8[0-245]|0[3-6]|4[3-5]|6[05-8]|2[0135]|3[0-369]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
     '155' => '(?:86(?:10|26|33|55|6[38]))',
     '156' => '(?:8(?:5(?:22|33|55|8[578]|0[126]|1[01])|6(?:66|78)))',
     '157' => '(?:85(?:01|43|50|6[1-35-7]|3[05]|2[0-2]|1[01]|7[035]))',
@@ -159,8 +159,8 @@ our %ZIP_TABLE = (
     '167' => '(?:8(?:5(?:[24]0|85|7[78]|3[34]|6[07]|0[167]|1[05]|5[15])|6(?:10|28|0[12])|0(?:01|70)))',
     '168' => '(?:8(?:5(?:[67]0|85|3[03]|5[058]|0[1-468]|2[05]|1[0-2])|6(?:01|26|[18][16])|081))',
     '169' => '(?:8(?:5(?:6[018]|2[0-25-7]|8[0568]|4[013]|7[07]|3[0135]|0[37-9]|1[015-7]|5[01568])|6(?:2[04]|5[056]|7[78]|0[1358]|1[0-36]|6[1468]|4[0458]|3[179])|0(?:50|77|1[12])|7(?:[01]1|22)|915))',
-    '170' => '(?:(?:8(?:4(?:1[015-79]|4[0-2478]|0[124-69]|7[067]|5[015-9]|6[0156]|2[0-467]|8[08]|3[02-468])|6(?:[68]6|12|53|0[25]|3[35])|5(?:51|85)|073)|6080))',
-    '171' => '(?:85(?:8[26]|5[02578]|3[19]|7[027]|4[045]|2[0-35-8]|1[0-2468]|6[0189]|0[1-37-9]))',
+    '170' => '(?:(?:8(?:4(?:1[015-79]|4[0-2478]|0[124-69]|7[067]|5[015-9]|6[0156]|2[0-467]|8[08]|3[02-468])|6(?:[68]6|12|0[25]|[35][35])|5(?:51|85)|073)|6080))',
+    '171' => '(?:85(?:8[26]|3[19]|7[027]|5[023578]|4[045]|2[0-35-8]|1[0-2468]|6[0189]|0[1-37-9]))',
     '173' => '(?:8(?:5(?:[06]1|30|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|66|3[29]|1[01]|0[1256])|710))',
     '174' => '(?:8(?:5(?:30|88|5[058]|6[07]|2[0146]|0[15])|6(?:01|12|46|3[369]|8[068])|7(?:[01]1|3[079]|4[0134])|860|903))',
     '175' => '(?:85(?:88|7[17]))',
@@ -195,7 +195,7 @@ our %ZIP_TABLE = (
     '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|8[568]|6[67]|0[235]|5[05]|1[125])|6(?:[68]6|11|0[12])))',
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:85|0[1-3]|5[05]))',
-    '210' => '(?:(?:8(?:5(?:3[127]|2[1-3]|5[027-9]|6[0259]|0[1246]|7[0167]|8[36]|1[125]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
+    '210' => '(?:(?:8(?:5(?:2[1-3]|5[027-9]|6[0259]|3[1278]|0[1246]|7[0167]|8[36]|1[125]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
     '211' => '(?:8(?:5(?:[2-4]0|66|5[058]|7[07]|8[58]|1[01]|0[125])|6(?:11|6[68])))',
     '212' => '(?:8(?:5(?:44|90|1[13]|0[1-389]|6[03467]|8[1-489]|2[05]|5[1457]|7[026]|3[016])|602))',
     '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|3[35]|7[0367]|8[015-9]|1[125]))',
@@ -205,7 +205,7 @@ our %ZIP_TABLE = (
     '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:8[06]|0[149]|1[1-6]|2[02]|7[48]|6[08])|080))',
     '221' => '(?:8(?:5(?:[46]0|37|88|2[0238]|1[17]|5[058])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
     '222' => '(?:8(?:5(?:77|3[03]|8[056]|6[1-6]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
-    '223' => '(?:8(?:5(?:1[025]|[58][058]|2[0-256]|7[27]|6[067]|4[0-2]|0[125-8]|3[039])|68[67]))',
+    '223' => '(?:8(?:5(?:1[025]|2[0-356]|[58][058]|7[27]|6[067]|4[0-2]|0[125-8]|3[039])|68[67]))',
     '224' => '(?:8(?:5(?:10|78|8[05]|0[1-5]|5[01]|3[039]|2[024])|68[68]|730))',
     '225' => '(?:85(?:[28]5|[56]0|13|3[59]|0[1-38]))',
     '226' => '(?:85(?:[25]5|1[02]|0[1-37]))',
@@ -218,7 +218,7 @@ our %ZIP_TABLE = (
     '236' => '(?:8(?:5(?:15|0[1-4]|5[05])|6(?:48|53)))',
     '237' => '(?:85(?:23|55|8[58]|1[05]))',
     '238' => '(?:(?:8(?:5(?:[04]1|33|8[058]|2[02]|6[57]|5[08]|1[01])|6[18]6)|029[28]))',
-    '239' => '(?:8(?:5(?:01|8[58])|68[68]))',
+    '239' => '(?:8(?:5(?:01|22|8[58])|68[68]))',
     '240' => '(?:(?:85(?:[02]1|[45]0|15)|019[2-8]))',
     '241' => '(?:8(?:5(?:15|0[12])|606))',
     '242' => '(?:8(?:5(?:[07]7|55)|6(?:01|10)))',
@@ -317,7 +317,7 @@ our %ZIP_TABLE = (
     '341' => '(?:85(?:01|5[058]|2[67]))',
     '342' => '(?:8(?:50[125]|601))',
     '343' => '(?:(?:8(?:5(?:11|40|85|5[45]|0[12])|601)|019[23]))',
-    '344' => '(?:8(?:5(?:[06]6|11|40|55|7[78]|3[35]|8[58]|2[12])|686))',
+    '344' => '(?:8(?:5(?:11|40|55|66|7[78]|3[35]|8[58]|2[12]|0[68])|686))',
     '345' => '(?:850[1248])',
     '346' => '(?:(?:8(?:5(?:[34]0|24|0[16])|68[56])|019[2-68]))',
     '347' => '(?:(?:85(?:67|85|0[1-4]|1[03]|5[05])|019[25]))',
@@ -380,10 +380,10 @@ our %ZIP_TABLE = (
     '404' => '(?:8[56]01)',
     '405' => '(?:85(?:[58]5|01|77))',
     '406' => '(?:8(?:5(?:05|10|5[58])|601))',
-    '407' => '(?:85(?:[01]1|55))',
+    '407' => '(?:85(?:[01]1|49|55))',
     '408' => '(?:(?:85(?:[18]5|22|33|5[05])|01(?:88|92)))',
     '409' => '(?:(?:3(?:8(?:9[2-8]|8[01357-9])|39[23]|79[23]|293|692)|2(?:19[2-6]|59[2378]|398|992)|1(?:298|392)|019[2358]))',
-    '410' => '(?:(?:8(?:5(?:67|0[148]|2[025]|5[0-258]|8[058]|3[0135]|7[05]|1[0145]|4[034])|6(?:10|8[69]|5[45]|0[12])|7(?:10|39))|2(?:39[2-6]|19[2-5]|29[257]|592)|1(?:39[2-6]|19[2356])|3(?:29[23]|69[36])|0(?:39[568]|192)))',
+    '410' => '(?:(?:8(?:5(?:67|0[148]|2[025]|5[0-258]|8[058]|3[0135]|7[05]|1[0145]|4[034])|6(?:10|8[69]|5[45]|0[12])|7(?:10|39))|2(?:39[2-6]|19[2-5]|29[257]|592)|1(?:19[2-6]|39[2-6])|3(?:29[23]|69[36])|0(?:39[568]|192)))',
     '411' => '(?:8(?:6(?:30|89|2[03]|4[148]|6[068]|5[0-2]|1[01])|5(?:02|33|60|77|2[05]|5[15]|[14][01])|7(?:[45]0|[78]7|2[025]|3[01])))',
     '412' => '(?:8(?:5(?:24|50|85|1[1-3]|0[15])|6(?:3[04]|0[159])))',
     '413' => '(?:(?:8(?:5(?:30|8[59]|0[25]|5[058]|6[067]|1[01])|6(?:26|78|1[18]))|0(?:29[238]|49[23]|196)))',
@@ -398,7 +398,7 @@ our %ZIP_TABLE = (
     '422' => '(?:8(?:5(?:[58]0|45|[26]\d|0[24-79]|7[0-8]|3[01]|1[0-24-9])|6(?:5[04]|3[03]|7[07]|8[068]|6[68]|1[059]|2[0-28])|766))',
     '424' => '(?:(?:8(?:6(?:48|50|0[1-3]|7[78]|3[1367]|[68][68]|1[01]|2[024])|7(?:3[04]|2[0147]|5[0-25]|6[07]|0[18]|1[579])|5(?:66|0[23]|5[058]|1[01]))|0(?:19[23]|292)))',
     '425' => '(?:8(?:5(?:[58]5|[67]0|11|22|33|0[1-358])|6(?:11|8[06])|7(?:11|0[18])))',
-    '426' => '(?:(?:8(?:6(?:01|3[13]|7[07]|1[27]|4[026]|6[2368])|5(?:39|43|1[015]|0[13]|7[057]|6[67])|7(?:11|22))|0292))',
+    '426' => '(?:(?:8(?:6(?:01|7[07]|3[1-38]|1[27]|4[026]|6[2368])|5(?:39|43|1[015]|0[13]|7[057]|6[67])|7(?:11|22))|0292))',
     '427' => '(?:(?:8(?:5(?:41|55|0[12589]|2[25]|8[18]|1[0-2])|6(?:86|0[12]))|019[356]))',
     '428' => '(?:(?:8(?:6(?:86|5[0-2])|50[1-3])|0192))',
     '430' => '(?:(?:8(?:5(?:[24]0|11|7[057]|6[07]|5[358]|8[0578]|3[036])|6(?:20|8[0679]|3[09]|7[0578]|6[578]|5[02-5]))|0898))',
@@ -424,7 +424,7 @@ our %ZIP_TABLE = (
     '450' => '(?:(?:8(?:5(?:40|3[0238]|2[0-3]|6[17]|1[05]|7[57]|8[035]|0[125])|6(?:[48]0|01|77|2[06]|1[148]|5[01])|7(?:11|30|65))|6133))',
     '451' => '(?:8(?:5(?:[14]1|85|[25][015]|6[0158]|0[1-38]|7[0157])|6(?:50|88)|701))',
     '452' => '(?:8(?:5(?:21|44|70|0[1-3]|6[1-79])|60[1-4]))',
-    '453' => '(?:8(?:5(?:[56]5|40|77|8[015]|2[12]|0[15]|3[039]|1[0-28])|6(?:[01]1|62|86)|765))',
+    '453' => '(?:8(?:5(?:[56]5|40|77|8[015]|2[12]|0[15]|3[039]|1[0-28])|6(?:[01]1|62|86)|7(?:65|77)))',
     '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[124-9]|6[05]|0[1-689])|651))',
     '455' => '(?:8(?:6(?:[07]1|[46]8|2[06]|3[09])|5(?:[1458]5|21|30|0[15])))',
     '456' => '(?:8(?:5(?:23|30|6[07]|1[16]|8[0578]|0[12]|5[56])|6(?:20|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
@@ -483,13 +483,13 @@ our %ZIP_TABLE = (
     '511' => '(?:(?:8(?:5(?:[67]7|02|33|5[058]|8[58]|1[01])|6(?:[68]6|01|78)|7(?:11|98))|0(?:29[2-6]|19[28]|59[23]|492)|1192))',
     '512' => '(?:85(?:12|38|50))',
     '513' => '(?:8(?:6(?:[57]0|01|8[06]|3[0-3]|6[016])|5(?:[1-3]0|0[15])|701))',
-    '514' => '(?:(?:8(?:5(?:4[0356]|3[0-38]|2[01468]|8[568]|7[0178]|5[02358]|1[1-58]|0[1-3578]|6[06-8])|6(?:[01]1|[68]6|3[35]))|2(?:39[23568]|29[2-4]|192)|1(?:29[2-7]|19[25])|039[235-7]))',
+    '514' => '(?:(?:8(?:5(?:4[0356]|3[0-38]|2[01468]|8[568]|7[01578]|5[02358]|1[1-58]|0[1-3578]|6[06-8])|6(?:[01]1|[68]6|3[35]))|2(?:39[23568]|29[2-4]|192)|1(?:29[2-7]|19[25])|039[235-7]))',
     '515' => '(?:(?:8(?:5(?:77|3[03]|2[25]|8[568]|6[67]|1[0135]|5[0578]|0[1359])|688)|2(?:69[23]|592)|059[2568]))',
     '516' => '(?:(?:8(?:5(?:20|77|5[0-58]|1[1568]|4[3-9]|6[67]|8[18]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
     '517' => '(?:(?:0(?:59[23]|292|494)|85(?:01|1[17])))',
     '518' => '(?:(?:0(?:49[2-68]|29[2-6]|192)|85(?:01|18|33)))',
     '519' => '(?:(?:0(?:19[35-8]|49[2357]|59[2-5]|292|393|696)|2(?:59[23]|[17]92)|3(?:69[2-6]|492)|439[2-6]|529[23]|1192))',
-    '520' => '(?:(?:8(?:5(?:[23]0|01|67|8[0568]|7[057]|5[058]|1[1-36])|6(?:39|66))|3(?:1(?:9[45]|8[02589])|08[0-58]|28[12589]|49[23]|393)|2(?:39[2-5]|59[24-6]|19[24]|492)|1(?:1(?:88|92)|[2568]92|49[25])|0(?:2(?:87|92)|58[08])))',
+    '520' => '(?:(?:8(?:5(?:[23]0|01|67|8[0568]|7[057]|5[058]|1[1-356])|6(?:39|66))|3(?:1(?:9[45]|8[02589])|08[0-58]|28[12589]|49[23]|393)|2(?:39[2-5]|59[24-6]|19[24]|492)|1(?:1(?:88|92)|[2568]92|49[25])|0(?:2(?:87|92)|58[08])))',
     '521' => '(?:(?:1(?:29[25]|39[28]|192)|8(?:60|5[0-2])1|0[23]92))',
     '522' => '(?:(?:8(?:5(?:11|40|3[39]|0[13]|8[58]|2[023])|6(?:55|66))|029[27]))',
     '523' => '(?:8(?:5(?:23|0[1-3]|5[58]|1[05])|651))',
@@ -499,7 +499,7 @@ our %ZIP_TABLE = (
     '527' => '(?:(?:8(?:5(?:[27]7|42|8[058]|6[67]|1[12]|5[0458]|0[589])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
-    '530' => '(?:(?:8(?:2(?:6[26]|1[0-25-7]|8[128]|2[27]|5[12]|4[157]|7[08]|0[13-6]|3[049])|5(?:01|35|44|2[1-3]|6[5-7]|5[1568]|7[45]|8[02368]|1[1-37])|3(?:2[134]|8[389]|4[16]|5[05]|1[18]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8])|6051))',
+    '530' => '(?:8(?:2(?:6[26]|1[0-25-7]|8[128]|2[27]|5[12]|4[157]|7[08]|0[13-6]|3[049])|5(?:01|35|44|2[1-3]|6[5-7]|5[1568]|7[45]|8[02368]|1[1-37])|3(?:18|2[34]|8[389]|4[16]|5[05]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8]))',
     '531' => '(?:8(?:5(?:11|67|0[1-3]|5[58])|787))',
     '532' => '(?:8(?:5(?:[38]5|60|77|2[045]|0[1578]|5[0258]|1[145])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
@@ -509,10 +509,10 @@ our %ZIP_TABLE = (
     '537' => '(?:8(?:5[01]1|686))',
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
-    '540' => '(?:(?:8(?:5(?:66|5[01589]|0[158]|3[03-5]|7[01578]|4[014]|2[267]|1[0-2579]|8[14-8])|6(?:20|8[69]|4[25]|3[09]|0[2-8]|7[078]|6[08]|1[01])|795)|6255))',
+    '540' => '(?:(?:8(?:5(?:66|2[1267]|5[01589]|0[158]|3[03-5]|7[01578]|4[014]|1[0-2579]|8[14-8])|6(?:20|8[69]|4[25]|3[09]|0[2-8]|7[078]|6[08]|1[01])|795)|6255))',
     '541' => '(?:(?:85(?:5[01346-9]|2[013-689]|3[0457-9]|4[0-35-9]|1[124-9]|6[3568]|8[13-79]|7[15-9]|0[1-689])|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
-    '543' => '(?:8(?:5(?:43|[58][58]|0[12])|6(?:01|66|8[68])))',
+    '543' => '(?:8(?:5(?:[34]3|11|[58][58]|0[12])|6(?:01|66|8[68])))',
     '544' => '(?:8(?:5(?:01|55)|666))',
     '545' => '(?:85(?:[01]1|22|33|45|5[058]|8[56]))',
     '546' => '(?:8501)',
@@ -556,7 +556,7 @@ our %ZIP_TABLE = (
     '586' => '(?:85(?:[58]5|01|77|2[18]|1[15]))',
     '587' => '(?:85(?:55|8[56]))',
     '589' => '(?:85(?:11|85|0[12]))',
-    '590' => '(?:(?:8(?:5(?:[34]0|77|0[13]|2[27-9]|1[17]|6[07]|8[58]|5[01])|686)|0(?:4(?:9[3-6]|8[12])|592)))',
+    '590' => '(?:(?:8(?:5(?:[34]0|03|77|2[27-9]|1[17]|6[07]|8[58]|5[01])|686)|0(?:4(?:9[3-6]|8[12])|592)))',
     '591' => '(?:85(?:11|55|0[125]))',
     '592' => '(?:8585)',
     '594' => '(?:(?:850[12]|1198))',
@@ -567,7 +567,7 @@ our %ZIP_TABLE = (
     '599' => '(?:(?:0[23]92|8531))',
     '600' => '(?:8(?:5(?:[347]0|1[019]|5[058]|8[1568]|6[67]|0[1-35])|6(?:52|77|86|6[56])|7(?:11|87)))',
     '601' => '(?:(?:85(?:01|42|50|3[03]|8[58]|1[01])|0(?:292|797)|1(?:192|495)))',
-    '602' => '(?:8(?:5(?:[01]1|55|66|70|8[058]|2[05])|611))',
+    '602' => '(?:8(?:5(?:[01]1|[27]0|55|66|8[058])|611))',
     '603' => '(?:85(?:11|22|55|77))',
     '604' => '(?:8(?:5(?:20|8[058]|7[178]|6[07]|5[01568]|1[01]|0[1-358])|666|798))',
     '605' => '(?:8(?:5[01]1|686))',
@@ -621,7 +621,7 @@ our %ZIP_TABLE = (
     '657' => '(?:85(?:01|70))',
     '658' => '(?:85(?:01|70|5[58]))',
     '659' => '(?:85(?:11|0[1-3]))',
-    '660' => '(?:85(?:[01]1|4[04]|8[058]|5[58]))',
+    '660' => '(?:85(?:[01]1|33|4[04]|8[058]|5[58]))',
     '661' => '(?:8(?:5(?:[23]0|01|77|85|6[47]|5[058]|1[01])|661))',
     '662' => '(?:85(?:[34]3|10|21|67|8[056]|5[258]|0[1-35]))',
     '663' => '(?:85(?:[67]7|01|10|45|58|8[568]))',
@@ -631,7 +631,7 @@ our %ZIP_TABLE = (
     '667' => '(?:(?:8(?:555|651)|0198))',
     '668' => '(?:(?:0(?:29[238]|393)|86(?:66|5[05])))',
     '669' => '(?:(?:3(?:39[24-6]|19[28]|69[23]|892)|5(?:19[2378]|39[258]|292)|6(?:[2578]92|19[25])|2(?:[12]92|397)|159[25]|4[13]92))',
-    '670' => '(?:8(?:5(?:43|3[03]|7[057]|8[058]|6[67]|5[0458]|2[024]|1[017]|0[1256])|6(?:8[0289]|7[057]|5[25]|6[068])))',
+    '670' => '(?:8(?:5(?:43|3[03]|7[057]|8[058]|6[67]|5[0458]|2[024]|1[017]|0[1256])|6(?:7[057]|5[25]|6[068]|8[029])))',
     '671' => '(?:(?:1(?:2(?:9[235]|8[0-35689])|6(?:92|8[0-248])|1(?:92|8[018])|59[235]|39[23])|2(?:59[2358]|19[238]|28[08])|419[23]|0295))',
     '672' => '(?:8(?:5(?:01|67|85|5[058])|6(?:55|66|77)))',
     '673' => '(?:(?:8(?:5(?:11|58|85)|6[68]6)|1(?:49[3-5]|192|395)|0[45]92))',
@@ -762,7 +762,7 @@ our %ZIP_TABLE = (
     '803' => '(?:8(?:5(?:20|43|3[0-35]|6[17]|5[058]|8[068]|1[0-357]|0[1458])|6(?:02|30|86|6[06])|787))',
     '804' => '(?:8(?:5(?:[12]0|77|88|0[135]|3[89]|5[058])|601))',
     '805' => '(?:8(?:5(?:[58]5|3[013-689]|2[0178]|0[1357-9]|1[02-468])|6(?:06|25)))',
-    '806' => '(?:8(?:5(?:67|70|4[03]|0[19]|5[58]|1[01]|8[56])|6(?:[68]6|79|1[12])))',
+    '806' => '(?:8(?:5(?:67|70|4[03]|0[19]|5[58]|1[01]|8[56])|6(?:[68]6|12|79)))',
     '807' => '(?:(?:85(?:01|8[568]|5[56])|019[28]|1392))',
     '808' => '(?:(?:8(?:5(?:02|1[045]|5[058]|8[58])|606)|0196))',
     '809' => '(?:8501)',
@@ -816,7 +816,7 @@ our %ZIP_TABLE = (
     '857' => '(?:(?:8(?:5(?:33|58|66|0[1-38]|8[58]|7[57]|1[01])|6(?:[68]6|11))|2(?:49[24]|392)|4(?:495|592)|119[23578]|0[134]92))',
     '858' => '(?:85(?:01|55|8[0589]))',
     '859' => '(?:(?:3(?:79[2378]|29[238]|692)|0(?:49[2578]|19[23])|(?:1[2-5]|6[24])92|4(?:59[5-8]|892)|5(?:39[23]|192)))',
-    '860' => '(?:8(?:5(?:4[1357]|3[0149]|7[057]|8[04-8]|0[1-47-9]|6[15-8]|5[0-24-8]|2[0-578]|1[0-8])|6(?:55|2[245]|8[168]|1[159]|0[1-68]|6[08])|79[157]))',
+    '860' => '(?:8(?:5(?:4[1357]|3[0149]|7[057]|8[04-8]|6[5-8]|0[1347-9]|5[0-24-8]|2[0-578]|1[0-8])|6(?:55|2[245]|8[168]|1[159]|0[1-68]|6[08])|79[57]))',
     '861' => '(?:(?:0(?:59[2-68]|19[58]|69[28]|89[28]|[39]92)|1(?:19[23578]|39[24]|295)|4(?:19[23578]|[34]92|696)|3(?:19[24-6]|29[56]|592)|2(?:29[235-7]|[14]92)|85(?:01|14|38|2[089])|5(?:49[2-5]|59[28])|6[13]95|7292))',
     '862' => '(?:8(?:6(?:6[06]|7[6-8]|2[02]|3[35]|0[139]|1[0-2]|8[08]|5[125])|7(?:20|44|1[06]|9[34]|0[12])|5(?:[127]0|0[258])))',
     '863' => '(?:(?:8(?:6(?:31|86)|5[58]5)|2(?:292|895)|1992))',
